==> haskell-mono-traversable-1.0.6.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.6.0
id: mono-traversable-1.0.6.0-2X9JSNJX1WWjiyTtREGF5
key: mono-traversable-1.0.6.0-2X9JSNJX1WWjiyTtREGF5
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>
category: Data
author: Michael Snoyman, John Wiegley, Greg Weber
exposed: True
indefinite: False
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences
hidden-modules: Paths_mono_traversable
abi: 1edf993e5502d9908c4457579b439af8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mono-traversable-1.0.6.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/mono-traversable-1.0.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mono-traversable-1.0.6.0
hs-libraries: HSmono-traversable-1.0.6.0-2X9JSNJX1WWjiyTtREGF5
depends:
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy
    split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj transformers-0.5.2.0
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    vector-algorithms-0.7.0.1-IlgMkkQzf7kBLgtLlabzVP
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy=6e4b4a70e10d525b7db51e3859aab169
             split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy=797cd4cd973bcc2d6f301fd097dd3406
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=db9131d5548eea6d7a3eab9f0d172004
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
             vector-algorithms-0.7.0.1-IlgMkkQzf7kBLgtLlabzVP=20be0bc6e88cd27702622527898b03d0
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.8.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.8.1
id: mono-traversable-1.0.8.1-3fXkW8Zk7Yj44e1ZDz26c2
key: mono-traversable-1.0.8.1-3fXkW8Zk7Yj44e1ZDz26c2
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>
category: Data
author: Michael Snoyman, John Wiegley, Greg Weber
exposed: True
indefinite: False
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences
hidden-modules: Paths_mono_traversable
abi: 3c0c1ac865778b82e9a300c22cfa6456
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mono-traversable-1.0.8.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/mono-traversable-1.0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mono-traversable-1.0.8.1
hs-libraries: HSmono-traversable-1.0.8.1-3fXkW8Zk7Yj44e1ZDz26c2
depends:
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj transformers-0.5.2.0
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    vector-algorithms-0.7.0.1-IlgMkkQzf7kBLgtLlabzVP
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy=797cd4cd973bcc2d6f301fd097dd3406
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
             vector-algorithms-0.7.0.1-IlgMkkQzf7kBLgtLlabzVP=20be0bc6e88cd27702622527898b03d0
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
